@@ -86,7 +86,7 @@ void MicroBlog::constraintsEvent(Plasma::Constraints constraints)
 {
     //i am an icon?
     if ((constraints|Plasma::SizeConstraint || constraints|Plasma::FormFactorConstraint) &&
-        layout()->itemAt(0) != m_graphicsWidget) {
+        layout() && layout()->itemAt(0) != m_graphicsWidget) {
         paintIcon();
     }
 }
@@ -254,7 +254,7 @@ QGraphicsWidget *MicroBlog::graphicsWidget()
     m_layout->addItem(m_scrollWidget);
 
     //hook up some sources
-    m_imageQuery = "UserImages:"+m_serviceUrl;
+    m_imageQuery = "UserImages:" + m_serviceUrl;
     m_engine->connectSource(m_imageQuery, this);
 
 
@@ -274,10 +274,10 @@ QGraphicsWidget *MicroBlog::graphicsWidget()
     return m_graphicsWidget;
 }
 
-void MicroBlog::modeChanged(int index)
+void MicroBlog::modeChanged(int)
 {
     m_tweetMap.clear();
-    m_lastTweet=0;
+    m_lastTweet = 0;
     downloadHistory();
 }
 
@@ -288,14 +288,14 @@ void MicroBlog::reply(const QString &to)
     QTextCursor cursor = m_statusEdit->nativeWidget()->textCursor();
     cursor.movePosition(QTextCursor::End);
     m_statusEdit->nativeWidget()->setTextCursor(cursor);
-    m_statusEdit->nativeWidget()->setFocus();
+    m_statusEdit->setFocus();
 }
 
 void MicroBlog::forward(const QString &rt)
 {
     m_scrollWidget->ensureItemVisible(m_headerFrame);
     m_statusEdit->nativeWidget()->setPlainText(rt);
-    m_statusEdit->nativeWidget()->setFocus();
+    m_statusEdit->setFocus();
 }
 
 void MicroBlog::getWallet()
@@ -394,7 +394,7 @@ void MicroBlog::dataUpdated(const QString& source, const Plasma::DataEngine::Dat
 {
     //kDebug() << source << data.count() << m_curTimeline;
     if (data.isEmpty()) {
-        if (source.startsWith("Error")) {
+        if (source.startsWith(QLatin1String("Error"))) {
             m_flash->kill(); //FIXME only clear it if it was showing an error msg
         } else {
             //this is a fake update from a new source
@@ -451,7 +451,7 @@ void MicroBlog::dataUpdated(const QString& source, const Plasma::DataEngine::Dat
                 m_pictureMap[user] = pm;
                 m_avatarHistory.removeAll(user);
                 m_avatarHistory.append(user);
-                if (m_avatarHistory.size() > 30) {
+                while (m_avatarHistory.size() > 30) {
                     QString oldestUser = m_avatarHistory.first();
                     m_avatarHistory.pop_front();
                     m_pictureMap.remove(oldestUser);
@@ -460,7 +460,7 @@ void MicroBlog::dataUpdated(const QString& source, const Plasma::DataEngine::Dat
                 scheduleShowTweets();
             }
         }
-    } else if (source.startsWith("Error")) {
+    } else if (source.startsWith(QLatin1String("Error"))) {
         QString desc = data["description"].toString();
 
         if (desc == "Authentication required"){
@@ -608,7 +608,7 @@ void MicroBlog::configAccepted()
         m_lastTweet = 0;
     }
 
-    m_imageQuery = "UserImages:"+m_serviceUrl;
+    m_imageQuery = "UserImages:" + m_serviceUrl;
     m_engine->connectSource(m_imageQuery, this);
 
     if (m_password != password) {
@@ -720,6 +720,10 @@ bool MicroBlog::eventFilter(QObject *obj, QEvent *event)
 
 void MicroBlog::updateStatus()
 {
+    if (!m_service) {
+        return;
+    }
+
     createTimelineService();
     QString status = m_statusEdit->nativeWidget()->toPlainText();
 
@@ -727,9 +731,7 @@ void MicroBlog::updateStatus()
     cg.writeEntry("password", m_password);
     cg.writeEntry("status", status);
 
-    if (m_updateJobs.isEmpty()) {
-        connect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(updateCompleted(Plasma::ServiceJob*)));
-    }
+    connect(m_service, SIGNAL(finished(Plasma::ServiceJob*)), this, SLOT(updateCompleted(Plasma::ServiceJob*)), Qt::UniqueConnection);
 
     m_updateJobs.insert(m_service->startOperationCall(cg));
     m_statusEdit->nativeWidget()->setPlainText("");
@@ -773,9 +775,12 @@ void MicroBlog::downloadHistory()
         m_service->startOperationCall(cg);
     } else {
         createTimelineService();
-        KConfigGroup cg = m_service->operationDescription("auth");
-        cg.writeEntry("password", m_password);
-        m_service->startOperationCall(cg);
+
+        if (m_service) {
+            KConfigGroup cg = m_service->operationDescription("auth");
+            cg.writeEntry("password", m_password);
+            m_service->startOperationCall(cg);
+        }
     }
 
     //get the profile to retrieve the user icon
