@@ -21,31 +21,30 @@
 
 #include "notes.h"
 
-#include <QFile>
-#include <QGraphicsGridLayout>
-#include <QGraphicsLinearLayout>
-#include <QGraphicsTextItem>
-#include <QMenu>
-#include <QScrollBar>
-#include <QTextStream>
-#include <QtGui/QtGui>
-#include <Plasma/PushButton>
-#include <KAction>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+
+#include <QtGui/QGraphicsGridLayout>
+#include <QtGui/QGraphicsTextItem>
+#include <QtGui/QScrollBar>
+#include <QtGui/QToolButton>
+#include <QtGui/QMenu>
+#include <QParallelAnimationGroup>
+
 #include <KConfigDialog>
 #include <KConfigGroup>
-#include <KFileDialog>
 #include <KGlobalSettings>
+#include <KFileDialog>
 #include <KMessageBox>
-#include <kicon.h>
-#include <kpushbutton.h>
-#include <KRichTextEdit>
+#include <KIcon>
+#include <KPushButton>
 #include <KStandardAction>
-#include <KTextEdit>
-#include <Plasma/TextEdit>
-
-
-
+#include <KAction>
 
+#include <Plasma/Animator>
+#include <plasma/animation.h>
+#include <Plasma/PushButton>
+#include <Plasma/Theme>
 
 NotesTextEdit::NotesTextEdit(QWidget *parent)
     : KRichTextEdit(parent),
@@ -68,9 +67,7 @@ void NotesTextEdit::setFormatMenu(QMenu *menu)
 void NotesTextEdit::contextMenuEvent( QContextMenuEvent *event )
 {
     QMenu *popup = mousePopupMenu();
-    popup->setWindowFlags(popup->windowFlags() | Qt::BypassGraphicsProxyWidget);
-    popup->setParent(0);
-    //popup->setParent(this);
+
     popup->addSeparator();
     popup->addAction(KStandardAction::saveAs(this, SLOT(saveToFile()), this));
 
@@ -186,26 +183,57 @@ PlasmaTextEdit::PlasmaTextEdit(QGraphicsWidget *parent)
 {
     KTextEdit *w = nativeWidget();
     native = new NotesTextEdit;
+    native->setWindowFlags(native->windowFlags() | Qt::BypassGraphicsProxyWidget);
     //FIXME: we need a way to just add actions without changing the native widget under its feet
     if (native->verticalScrollBar() && w->verticalScrollBar()) {
         native->verticalScrollBar()->setStyle(w->verticalScrollBar()->style());
     }
-    connect(native, SIGNAL(textChanged()), this, SIGNAL(textChanged()));
+    setNativeWidget(native);
+
     connect(native, SIGNAL(cursorMoved()), this, SIGNAL(textChanged()));
     connect(native, SIGNAL(mouseUnhovered()), this, SIGNAL(mouseUnhovered()));
 
     // scrollwheel + ctrl changes font size
     connect(native, SIGNAL(scrolledUp()), parent, SLOT(increaseFontSize()));
     connect(native, SIGNAL(scrolledDown()), parent, SLOT(decreaseFontSize()));
-    setWidget(native);
-    delete w;
-    native->setAttribute(Qt::WA_NoSystemBackground);
 }
 
 PlasmaTextEdit::~PlasmaTextEdit()
 {
 }
 
+void PlasmaTextEdit::mousePressEvent(QGraphicsSceneMouseEvent *event)
+{
+    QGraphicsWidget *widget = parentWidget();
+    Plasma::Applet *applet = qobject_cast<Plasma::Applet *>(widget);
+
+    while (!applet && widget) {
+        widget = widget->parentWidget();
+        applet = qobject_cast<Plasma::Applet *>(widget);
+    }
+
+    if (applet) {
+        applet->setStatus(Plasma::AcceptingInputStatus);
+    }
+    QGraphicsProxyWidget::mousePressEvent(event);
+}
+
+void PlasmaTextEdit::focusOutEvent(QFocusEvent *event)
+{
+    QGraphicsWidget *widget = parentWidget();
+    Plasma::Applet *applet = qobject_cast<Plasma::Applet *>(widget);
+
+    while (!applet && widget) {
+        widget = widget->parentWidget();
+        applet = qobject_cast<Plasma::Applet *>(widget);
+    }
+
+    if (applet) {
+        applet->setStatus(Plasma::UnknownStatus);
+    }
+    QGraphicsProxyWidget::focusOutEvent(event);
+}
+
 /**
  * Save content to file
  */
@@ -254,6 +282,7 @@ Notes::Notes(QObject *parent, const QVariantList &args)
       m_layout(0),
       m_textEdit(0)
 {
+    setStatus(Plasma::AcceptingInputStatus);
     setAspectRatioMode(Plasma::IgnoreAspectRatio);
     setHasConfigurationInterface(true);
     setAcceptDrops(true);
@@ -264,9 +293,9 @@ Notes::Notes(QObject *parent, const QVariantList &args)
     resize(256, 256);
 
     m_textEdit = new PlasmaTextEdit(this);
-    m_textEdit->setMinimumSize(QSize(0, 0));
+    m_textEdit->setMinimumSize(QSize(60, 60)); //Ensure a minimum size (height) for the textEdit
     m_layout = new QGraphicsLinearLayout(Qt::Vertical);
-    m_layout->setSpacing(0);
+    m_layout->setSpacing(2); //We need a bit of spacing between the edit and the buttons
     m_textEdit->nativeWidget()->setFrameShape(QFrame::NoFrame);
     m_textEdit->nativeWidget()->viewport()->setAutoFillBackground(false);
     m_layout->addItem(m_textEdit);
@@ -280,10 +309,6 @@ Notes::Notes(QObject *parent, const QVariantList &args)
             m_textEdit->nativeWidget()->setHtml(t.readAll());
             f.close();
         }
-    } else {
-#ifdef KTEXTEDIT_CLICKMSG_SUPPORT
-        m_textEdit->nativeWidget()->setClickMessage(i18n("Welcome to the Notes Plasmoid! Type your notes here..."));
-#endif
     }
 
     createTextFormatingWidgets();
@@ -320,7 +345,14 @@ void Notes::init()
     KConfigGroup cg = config();
     m_color = cg.readEntry("color", "yellow");
     // color must be before setPlainText("foo")
-    m_textColor = cg.readEntry("textColor", QColor(Qt::black));
+    m_useThemeColor = cg.readEntry("useThemeColor", true);
+    m_useNoColor = cg.readEntry("useNoColor", true);
+    if (m_useThemeColor) {
+        m_textColor = Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor);
+        connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
+    } else {
+        m_textColor = cg.readEntry("textColor", m_textColor);
+    }
     m_textBackgroundColor = cg.readEntry("textBackgroundColor", QColor(Qt::transparent));
     m_textEdit->nativeWidget()->setTextColor(m_textColor);
 
@@ -348,19 +380,16 @@ void Notes::init()
     m_textEdit->nativeWidget()->selectAll();
     m_textEdit->nativeWidget()->setFontFamily(m_font.family());
     m_textEdit->nativeWidget()->setTextCursor(oldCursor);
-    
-    m_customFontSize = cg.readEntry("customFontSize", m_font.pointSize());
-    m_autoFont = cg.readEntry("autoFont", true);
-    m_autoFontPercent = cg.readEntry("autoFontPercent", 4);
 
-    m_useThemeColor = cg.readEntry("useThemeColor", true);
-    m_useNoColor = cg.readEntry("useNoColor", true);
+    m_customFontSize = cg.readEntry("customFontSize", m_font.pointSize());
+    m_autoFont = cg.readEntry("autoFont", false);
+    m_autoFontPercent = cg.readEntry("autoFontPercent", 4);
 
     m_checkSpelling = cg.readEntry("checkSpelling", false);
     m_textEdit->nativeWidget()->setCheckSpellingEnabled(m_checkSpelling);
     updateTextGeometry();
 
-    connect(m_textEdit, SIGNAL(textChanged()), this, SLOT(delayedSaveNote())); 
+    connect(m_textEdit, SIGNAL(textChanged()), this, SLOT(delayedSaveNote()));
     connect(m_textEdit, SIGNAL(textChanged()), this, SLOT(lineChanged()));
     connect(m_textEdit, SIGNAL(mouseUnhovered()), this, SLOT(mouseUnhovered()));
 }
@@ -376,9 +405,9 @@ void Notes::lineChanged()
         QTextCharFormat fmt;
         fmt.setForeground(QBrush(m_textColor));
         fmt.setFont(m_font);
-        m_textEdit->nativeWidget()->setCurrentCharFormat(fmt);   
+        m_textEdit->nativeWidget()->setCurrentCharFormat(fmt);
     }
-    
+
     if (m_useNoColor) {
         return;
     }
@@ -427,7 +456,7 @@ void Notes::updateTextGeometry()
         m_textEdit->nativeWidget()->selectAll();
         m_textEdit->nativeWidget()->setFontPointSize(m_font.pointSize());
         m_textEdit->nativeWidget()->setTextCursor(oldTextCursor);
-        
+
         if (m_autoFont) {
             lineChanged();
         }
@@ -473,6 +502,12 @@ void Notes::saveNote()
     emit configNeedsSaving();
 }
 
+void Notes::themeChanged()
+{
+    m_textColor = Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor);
+    update();
+}
+
 void Notes::addColor(const QString &id, const QString &colorName)
 {
     if (m_notesTheme.hasElement(id + "-notes")) {
@@ -556,7 +591,7 @@ void Notes::createConfigurationInterface(KConfigDialog *parent)
 
     QList<QAction *> colorActions = m_colorMenu->actions();
     for (int i = 0; i < colorActions.size(); i++){
-        QString text = colorActions.at(i)->text();
+        QString text = colorActions.at(i)->text().remove('&');
         if (!text.isEmpty()){
             ui.notesColorComboBox->insertItem(i, text);
             if (colorActions.at(i)->property("color").toString() == m_color) {
@@ -574,7 +609,7 @@ void Notes::configAccepted()
     QFont newFont = ui.fontStyleComboBox->currentFont();
     newFont.setBold(ui.fontBoldCheckBox->isChecked());
     newFont.setItalic(ui.fontItalicCheckBox->isChecked());
-    
+
     //Apply bold and italic changes (if any) here (this is destructive formatting)
     bool boldChanged = (m_font.bold() != newFont.bold());
     bool italicChanged = (m_font.italic() != newFont.italic());
@@ -591,14 +626,14 @@ void Notes::configAccepted()
         //Restore previous selection
         m_textEdit->nativeWidget()->setTextCursor(oldCursor);
     }
-    
+
     //Save font settings to config
     if (m_font != newFont) {
         changed = true;
         cg.writeEntry("font", newFont);
         m_font = newFont;
-        
-        //Apply font size
+
+        //Apply font family
         QTextCursor oldCursor = m_textEdit->nativeWidget()->textCursor();
         m_textEdit->nativeWidget()->selectAll();
         m_textEdit->nativeWidget()->setFontFamily(m_font.family());
@@ -623,18 +658,28 @@ void Notes::configAccepted()
         cg.writeEntry("autoFontPercent", m_autoFontPercent);
     }
 
-    //TODO
+    disconnect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
+    bool textColorChanged = false;
     if (m_useThemeColor != ui.useThemeColor->isChecked()) {
         changed = true;
+        textColorChanged = true;
         m_useThemeColor = ui.useThemeColor->isChecked();
         cg.writeEntry("useThemeColor", m_useThemeColor);
+        m_textColor = Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
+        connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
     }
 
-    QColor newColor = ui.textColorButton->color();
-    if (m_textColor != newColor) {
-        changed = true;
-        m_textColor = newColor;
-        cg.writeEntry("textColor", m_textColor);
+    if (!m_useThemeColor) {
+        QColor newColor = ui.textColorButton->color();
+        if (m_textColor != newColor) {
+            changed = true;
+            textColorChanged = true;
+            m_textColor = newColor;
+            cg.writeEntry("textColor", m_textColor);
+        }
+    }
+
+    if (textColorChanged) {
         QTextCursor textCursor = m_textEdit->nativeWidget()->textCursor();
         m_textEdit->nativeWidget()->selectAll();
         m_textEdit->nativeWidget()->setTextColor(m_textColor);
@@ -673,11 +718,14 @@ void Notes::configAccepted()
     }
 
     QList<QAction *> colorActions = m_colorMenu->actions();
-    QString tmpColor = colorActions[ui.notesColorComboBox->currentIndex()]->property("color").toString();
-    if (tmpColor != m_color){
-        m_color = tmpColor;
-        cg.writeEntry("color", m_color);
-        changed = true;
+    QAction *colorAction = colorActions.value(ui.notesColorComboBox->currentIndex());
+    if (colorAction) {
+        QString tmpColor = colorAction->property("color").toString();
+        if (tmpColor != m_color){
+            m_color = tmpColor;
+            cg.writeEntry("color", m_color);
+            changed = true;
+        }
     }
 
     if (changed) {
@@ -691,7 +739,7 @@ void Notes::createTextFormatingWidgets()
 {
     m_formatMenu = new QMenu(i18n("Formatting"));
     m_textEdit->native->setFormatMenu(m_formatMenu);
-    QAction *actionBold = m_formatMenu->addAction(KIcon("format-text-bold"), i18n("Bold")); 
+    QAction *actionBold = m_formatMenu->addAction(KIcon("format-text-bold"), i18n("Bold"));
     QAction *actionItalic = m_formatMenu->addAction(KIcon("format-text-italic"),i18n("Italic"));
     QAction *actionUnderline = m_formatMenu->addAction(KIcon("format-text-underline"), i18n("Underline"));
     QAction *actionStrikeThrough = m_formatMenu->addAction(KIcon("format-text-strikethrough"), i18n("StrikeOut"));
@@ -703,6 +751,12 @@ void Notes::createTextFormatingWidgets()
     connect(actionStrikeThrough, SIGNAL(triggered()), m_textEdit->native, SLOT(strikeOut()));
     connect(actionCenter, SIGNAL(triggered()), m_textEdit->native, SLOT(justifyCenter()));
     connect(actionFill, SIGNAL(triggered()), m_textEdit->native, SLOT(justifyFill()));
+    connect(actionItalic, SIGNAL(triggered()), this, SLOT(updateOptions()));
+    connect(actionBold, SIGNAL(triggered()), this, SLOT(updateOptions()));
+    connect(actionUnderline, SIGNAL(triggered()), this, SLOT(updateOptions()));
+    connect(actionStrikeThrough, SIGNAL(triggered()), this, SLOT(updateOptions()));
+    connect(actionCenter, SIGNAL(triggered()), this, SLOT(updateOptions()));
+    connect(actionFill, SIGNAL(triggered()), this, SLOT(updateOptions()));
 
     QGraphicsWidget *widget = new QGraphicsWidget(this);
     widget->setMaximumHeight(25);
@@ -746,19 +800,49 @@ void Notes::createTextFormatingWidgets()
 
     m_layout->addItem(widget);
 
+    m_buttonAnimGroup = new QParallelAnimationGroup(this);
+
+    for (int i = 0; i < 6; i++){
+        m_buttonAnim[i] = Plasma::Animator::create(Plasma::Animator::FadeAnimation, this);
+        m_buttonAnimGroup->addAnimation(m_buttonAnim[i]);
+    }
+
+    m_buttonAnim[0]->setTargetWidget(m_buttonBold);
+    m_buttonAnim[1]->setTargetWidget(m_buttonItalic);
+    m_buttonAnim[2]->setTargetWidget(m_buttonUnderline);
+    m_buttonAnim[3]->setTargetWidget(m_buttonStrikeThrough);
+    m_buttonAnim[4]->setTargetWidget(m_buttonCenter);
+    m_buttonAnim[5]->setTargetWidget(m_buttonFill);
+
     showOptions(false);
     connect(m_buttonOption->nativeWidget(), SIGNAL(toggled(bool)), this, SLOT(showOptions(bool)));
+    
+    connect(m_textEdit->nativeWidget(), SIGNAL(cursorPositionChanged()), this, SLOT(updateOptions()));
 }
 
 void Notes::showOptions(bool show)
 {
     m_buttonOption->nativeWidget()->setDown(show);
-    m_buttonBold->setVisible(show);
-    m_buttonItalic->setVisible(show);
-    m_buttonUnderline->setVisible(show);
-    m_buttonStrikeThrough->setVisible(show); 
-    m_buttonCenter->setVisible(show);
-    m_buttonFill->setVisible(show);
+
+    qreal targetOpacity = show ? 1 : 0;
+    qreal startOpacity = 1 - targetOpacity;
+
+    for (int i = 0; i < 6; i++){
+        m_buttonAnim[i]->setProperty("startOpacity", startOpacity);
+        m_buttonAnim[i]->setProperty("targetOpacity", targetOpacity);
+    }
+
+    m_buttonAnimGroup->start();
+}
+
+void Notes::updateOptions()
+{
+    m_buttonBold->setDown(m_textEdit->nativeWidget()->fontWeight() == QFont::Bold);
+    m_buttonItalic->setDown(m_textEdit->nativeWidget()->fontItalic());
+    m_buttonUnderline->setDown(m_textEdit->nativeWidget()->fontUnderline());
+    m_buttonStrikeThrough->setDown(m_textEdit->nativeWidget()->currentFont().strikeOut());
+    m_buttonCenter->setDown(m_textEdit->nativeWidget()->alignment() == Qt::AlignHCenter);
+    m_buttonFill->setDown(m_textEdit->nativeWidget()->alignment() == Qt::AlignJustify);
 }
 
 #include "notes.moc"
