@@ -23,6 +23,8 @@
 
 // Qt includes
 #include <QPainter>
+#include <QEasingCurve>
+#include <QPropertyAnimation>
 
 // KDE includes
 #include <KFileDialog>
@@ -49,6 +51,8 @@ WeatherWallpaper::WeatherWallpaper(QObject * parent, const QVariantList & args )
     , m_weatherLocation(0)
     , m_advancedDialog(0)
     , m_fileDialog(0)
+    , m_fadeValue(0)
+    , m_animation(0)
     , m_model(0)
     , m_newStuffDialog(0)
 {
@@ -57,6 +61,7 @@ WeatherWallpaper::WeatherWallpaper(QObject * parent, const QVariantList & args )
 
 WeatherWallpaper::~WeatherWallpaper()
 {
+    delete m_animation;
 }
 
 void WeatherWallpaper::init(const KConfigGroup & config)
@@ -73,7 +78,12 @@ void WeatherWallpaper::init(const KConfigGroup & config)
     m_usersWallpapers = config.readEntry("userswallpapers", QStringList());
     m_resizeMethod = (ResizeMethod)config.readEntry("wallpaperposition", (int)ScaledResize);
 
-    m_weatherMap["weather-none-available"] = Plasma::Theme::defaultTheme()->wallpaperPath();
+    m_animation = new QPropertyAnimation(this, "fadeValue");
+    m_animation->setProperty("easingCurve", QEasingCurve::InQuad);
+    m_animation->setProperty("duration", 1000);
+    m_animation->setProperty("startValue", 0.0);
+    m_animation->setProperty("endValue", 1.0);
+
     m_weatherMap["weather-clear"] = config.readEntry("clearPaper", m_dir + "Fields_of_Peace/");
     m_weatherMap["weather-few-clouds"] = config.readEntry("partlyCloudyPaper", m_dir + "Evening/");
     m_weatherMap["weather-clouds"] = config.readEntry("cloudyPaper", m_dir + "Colorado_Farm/");
@@ -83,12 +93,13 @@ void WeatherWallpaper::init(const KConfigGroup & config)
     m_weatherMap["weather-rain"] = config.readEntry("rainPaper", m_dir + "There_is_Rain_on_the_Table/");
     m_weatherMap["weather-mist"] = config.readEntry("mistPaper", m_dir + "Fresh_Morning/");
     m_weatherMap["weather-storm"] = config.readEntry("stormPaper", m_dir + "Lightning/");
+    m_weatherMap["weather-scattered-storms"] = m_weatherMap["weather-storm"];
     m_weatherMap["weather-hail"] = config.readEntry("hailPaper", m_dir + "Lightning/");
     m_weatherMap["weather-snow"] = config.readEntry("snowPaper", m_dir + "Winter_Track/");
     m_weatherMap["weather-snow-scattered"] = config.readEntry("snowScatteredPaper", m_dir + "Winter_Track/");
     m_weatherMap["weather-few-clouds-night"] = config.readEntry("partlyCloudyNightPaper", m_dir + "JK_Bridge_at_Night/");
     m_weatherMap["weather-clouds-night"] = config.readEntry("cloudyNightPaper", m_dir + "JK_Bridge_at_Night/");
-    m_weatherMap["weather-clear-night"] = config.readEntry("clearNightPaper", m_dir + "At_Night/");
+    m_weatherMap["weather-clear-night"] = config.readEntry("clearNightPaper", m_dir + "City_at_Night/");
     m_weatherMap["weather-freezing-rain"] = config.readEntry("freezingRainPaper", m_dir + "Icy_Tree/");
     m_weatherMap["weather-snow-rain"] = config.readEntry("snowRainPaper", m_dir + "Icy_Tree/");
 
@@ -213,7 +224,18 @@ void WeatherWallpaper::paint(QPainter * painter, const QRectF & exposedRect)
 
 void WeatherWallpaper::loadImage()
 {
-    m_wallpaper = m_weatherMap[m_condition];
+    m_wallpaper = m_weatherMap.value(m_condition);
+
+    if (m_wallpaper.isEmpty()) {
+       QHashIterator<QString, QString> it(m_weatherMap);
+       while (it.hasNext()) {
+           it.next();
+           if (m_condition.startsWith(it.key())) {
+               m_wallpaper = it.value();
+               break;
+           }
+       }
+    }
 
     if (m_wallpaper.isEmpty()) {
         m_wallpaper = Plasma::Theme::defaultTheme()->wallpaperPath();
@@ -254,7 +276,7 @@ void WeatherWallpaper::showAdvancedDialog()
         m_advancedUi.m_wallpaperView->view()->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
 
         connect(m_advancedUi.m_conditionCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(conditionChanged(int)));
-        m_advancedUi.m_conditionCombo->addItem(KIcon("weather-clear"), i18n("Clear"), "weather-clear");
+        m_advancedUi.m_conditionCombo->addItem(KIcon("weather-clear"), i18nc("weather condition", "Clear"), "weather-clear");
         m_advancedUi.m_conditionCombo->addItem(KIcon("weather-few-clouds"), i18n("Partly Cloudy"), "weather-few-clouds");
         m_advancedUi.m_conditionCombo->addItem(KIcon("weather-clouds"), i18n("Cloudy"), "weather-clouds");
         m_advancedUi.m_conditionCombo->addItem(KIcon("weather-many-clouds"), i18n("Very Cloudy"), "weather-many-clouds");
@@ -526,7 +548,7 @@ void WeatherWallpaper::updateBackground(const QImage &img)
     m_pixmap = QPixmap::fromImage(img);
 
     if (!m_oldPixmap.isNull()) {
-        Plasma::Animator::self()->customAnimation(254, 1000, Plasma::Animator::EaseInCurve, this, "updateFadedImage");
+        m_animation->start();
     } else {
         emit update(boundingRect());
     }
@@ -539,10 +561,17 @@ void WeatherWallpaper::updateScreenshot(QPersistentModelIndex index)
     }
 }
 
-void WeatherWallpaper::updateFadedImage(qreal frame)
+qreal WeatherWallpaper::fadeValue()
 {
+    return m_fadeValue;
+}
+
+void WeatherWallpaper::setFadeValue(qreal value)
+{
+    m_fadeValue = value;
+
     //If we are done, delete the pixmaps and don't draw.
-    if (frame == 1) {
+    if (qFuzzyCompare(m_fadeValue, qreal(1.0))) {
         m_oldFadedPixmap = QPixmap();
         m_oldPixmap = QPixmap();
         emit update(boundingRect());
@@ -557,7 +586,8 @@ void WeatherWallpaper::updateFadedImage(qreal frame)
     p.drawPixmap(0, 0, m_oldPixmap);
 
     p.setCompositionMode(QPainter::CompositionMode_DestinationIn);  
-    p.fillRect(m_oldFadedPixmap.rect(), QColor(0, 0, 0, 254 * (1-frame)));//255*((150 - frame)/150)));
+    p.fillRect(m_oldFadedPixmap.rect(), QColor(0, 0, 0, 254 * (1-m_fadeValue)));//255*((150 - m_fadeValue)/150)));
+
     p.end();
 
     emit update(boundingRect());
